Welcome to our World! Where we serve you cookies to ensure you get the best viewing experience on our site.

Did you know that you can remove censorship board-wide, use our advanced search functions, be notified when new content is posted, join our memberships, set episodes to show in any order you want & more if you are logged into your account?

Register or sign in here: ucp.php?mode=register

15x10 - A Power Trip

Episode transcripts for the TV show, "Project Runway". Aired: December 1, 2004 – present.*
Watch/Buy Amazon


Contestants compete with each other to create the best clothes and are restricted by time, materials and theme.

15x10 - A Power Trip

Post by bunniefuu »

HEIDI:
Previously on Project Runway...

To help inspire you,

we've brought some
very special people.

Mommy!
[laughs]

TIM: These individuals
will serve as your clients.

I can also play up a little
shoulder action, too.

-Mm-hmm.
-I got you, Mom.

We have the wedding,
my birthday,

and the graduation thing
at the school.

She is all over the place.

Erin, how many times have we
seen this coat?

Put it on right now!

♪ ♪

You look badass.

-Yeah. Your son really
did a great job. -Yay.

It looks like a real
designer dress.

Rik, congratulations.

You are the winner of
this challenge.

[squealing]

You will each receive

$25,000 from AARP.

[voice breaking]:
Thank you.

It doesn't really suit her.

The silhouette is just wrong.

And it looks like
there's a pin in it.

There's too many messages.

It looks sloppy.

I'm sorry, Jenni,

that means you're out.

♪ ♪

[horn honking]

DEXTER:
I'm a little shocked

that you didn't win win
that last challenge.

I was running around screaming,
"Mah-Jing for president."

-[chuckles]
-That doesn't mean

it's a total loss to me,

'cause I want my relationship

back with my mom,

which is more important
than $25,000.

MAH-JING:
I'm very grateful right now.

I feel like the inner Mah-Jing

is about to start really
coming out--

like, that beast in me.

How do you feel, Cori?
Being safe.

I did not want to be up there
in front of the judges.

I thought they were gonna
hate the print.

CORNELIUS: The competition is
down to the wire,

Fashion Week is
right around the corner.

I'm a very strong designer

and I'm hoping that the judges

can finally see it.

LAURENCE:
We got a note.

"Hi, designers.
For your next challenge,

"be sure to have your heads
out of the clouds.

"After all, you just can't

wing it and win it."

"Go meet Tim
and a special guest.

"And remember,
the sky is still the limit

for all you."

"This is anyone's game.
I'll see you

back on the runway. Heidi."

Nuh-uh.

I hope we go hot air ballooning.

I'm thinking something
with feathers.

Like, what if they take us to,
like,

a bird sanctuary and we have to
get inspired by birds?

If the birds are large
and they're ostriches,

I am effed.

-[squawking]
-Skydiving?

♪ ♪

[jet engines roaring]

TIM: How about this
incredible view that we have?

What a trip.

-I know.
-It's been amazing.

TIM: I'm so excited for you
to meet the designers.

ANNE:
Love it.

MAH-JING:
Helicopters.

I don't like heights.

-I love the Project Runway
helicopter. -I do, too.

Why did it take us 15 seasons
to figure out we had one?

ERIN: No wonder
Tim is always on time,

he has a helicopter.

I need one of those.

Good morning, designers.

ALL:
Good morning.

I am delighted and thrilled
to introduce you

to Anne Fulenwider,

editor-in-chief of
Marie Claire magazine.

-[designers oohing]
-TIM: Welcome, Anne.

-ANNE: Thank you, Tim.
Hi, designers. -Hi.

At Marie Claire,
we celebrate powerful women.

Whether it's fashion, beauty,
advice, or news, we stress

the importance of making women
feel confident and powerful.

TIM: So, designers,
with that in mind,

today, we've decided

to send you all on a power trip.

So, we're sending you

in a helicopter to get

an aerial view of New York City.

-[cheering, whooping]
-Wow.

Yay!

While you're in the air,

absorb everything around you.

ANNE: We want you to use
this unique perspective

to influence your next look.

This is a city of power players,
everyone.

So for this challenge,

we want you to create

an editorial look
for a powerful woman.

ANNE: And let me stress to you
that an editorial look

is not "everyday."

Designers, think bold,
high-fashion and drama.

We at Marie Claire are
enlisting you to help us out.

The winning look of
this challenge will be

featured in a spread of
Marie Claire magazine.

-[applause]
-[Erin squealing]

TIM: This is a huge opportunity
for all of you.

DEXTER:
I won one already,

so if I could win two of those

and be in Marie Claire
and repeat,

then the Marie Claire readers
would start to get used to me

and then maybe Marie Claire
might call me back

to do more stuff.

So, designers, after you land,

you will have 30 minutes
to sketch,

and then we're going to Mood,

where you will have a budget
of $300,

and you have one day
for this challenge.

RIK: It's a little
nerve-racking,

'cause an editorial look does
take a while to conceive.

ANNE:
Good luck, designers.

I'll see you tomorrow
on the runway.

-Bye.
-See you later.

-Thank you.
-Bye.

♪ ♪

ERIN:
It's like, a little like...

-[Erin vibrating]
-[Dexter laughs]

♪ ♪

[horns honking]

CORNELIUS: So, I'm taking photos
of architecture,

like different buildings,

colorful buildings--
there was red, yellow.

I might have to show that
in my look.

[squealing, chuckling]

DEXTER: I start to, kind of,
go off in my little world.

And I should be, like, talking
and, like,

giggling with everyone,
and playing like,

"Oh, my God, I'm having fun."
But I'm like--

I'm like gone.
I'm like, somewhere else,

which is usually when
I do my best work.

NATHALIA:
That was so cool.

Such a cute little landing.

Oh...

-RIK: That was dope.
-ERIN: Thank you.

[whooping]

ROBERI:
I'm not taking any car anymore.

From now on,

just helicopter for me, please.

[helicopter blades whirring]

You could sit next to me.

I don't want you to see
what I'm doing.

DEXTER: Oh, my--
look at that lighting.

ERIN: I had my little moment of
questioning everything and

I was a little insecure,

but I'm feeling really positive

about myself again,

and kind of being like,
"All right,

let's show them
that I'm good again."

DEXTER: My brain is
going a little gothy.

You know, the city can be
a dark place.

My inspiration isn't as,
like, bubbly

and colorful as everyone else's.

CORNELIUS:
I'm envisioning pops of color.

I don't know where I'm going to
place them,

but I do know
that I want things to kind of,

protrude off the body.

TIM:
All right, designers.

Sketching time is up.

Let's head off to Mood.

ERIN: I actually do
always want do yellow

'cause I do always think of,
like, yellow cabs in New York.

But I really want to
push myself

with, like, color choice.

One more. Can I please get
one yard of this and then,

can you bring it down for me,
please?

-Okay.
-I get a silver fabric.

I pick up some Neoprene.

I'm envisioning this, like,

super powerful woman,

that kind of looks like
a superhero.

Awesome. Thank you.

Do you know where I could find,
like, spandex lace?



Aisle four?

DEXTER:
I'm envisioning, like,

a see-through lace dress.

There's nothing wrong with

a little exposed poom poom
on the runway.

It's supposed to be editorial.

LAURENCE:
All right. Thank you.

RIK:
Thank you so much.

All right.
Back to the workroom, designers.

Merci, Mood.

[Swatch barks]

♪ ♪

Cori, did you buy out
the leather section?

-I bought every color.
-I like this one.

The lime green one? Yeah.

TIM: Good heavens,
there's so many fewer of you.

-ERIN: I know, it's weird.
-DEXTER: Hi, Tim.

TIM:
I'm coming in

on the earlier side
for critiques,

because I want you all to have

more time to evolve.

Your models will not be in until
between 8:30 and 9:00.

You have until 1:00 tonight.

And please take advantage
of the Brother sewing room.

-Thanks, Tim.
-[blows kiss] Thank you.

I'm definitely thinking
outside of the box on this one.

This floor is gonna be
[bleep] up.

The judges have seen me do

very tailored,
very well-polished looks,

so I kind of wanted to
take a risk with this,

using this treatment that

hasn't really been seen before.

This definitely has to work
for me.

I'm hoping it doesn't

look like a m*rder scene.

It's a bloody mess over there.

CORNELIUS:
I think I'm the only one here

that has not won a challenge.

I was brought back by Tim
and honestly,

I just want to make him proud.

NATHALIA:
Well, what you're making today

might get you a win,
you never know.

CORNELIUS:
I am here to work

and to show the best garments
that I can create.

NATHALIA: I don't want
to sh**t myself in the foot.

-RIK: No, especially with the
big jacket. -Oh, my God.

I need to move on, you know,
forget about it.

-This is a new week.
-It's the past,

-this is a new day.
-Exactly.

Quiet...

Focused.

So, Rik, tell me
about your inspiration.

I'm getting inspiration
from the Statue of Liberty.

I'm going to use
this white stretch denim...

-Mm-hmm.
-...underneath,

and then the top layer
is silk-cotton voile.

-Where is the voile? -I'm doing
this dye treatment to it.

-Let's go look.
-Yeah, let's check it out.

TIM:
I love this.

-Thank you.
-In fact... fact,

-I'm crazy about it.
-Oh, great.

TIM:
This is stunning.

And it's so personal,

-and personalized.
-Thank you.

MAH-JING: What Rik has done,
I do to my stuff at home.

But see, I have a certain way of
doing it where it actually...

looks dope.

Mah-Jing.

I wanted to do something
that was strong,

very close to my African side.

-Uh-huh.
-Edgy and interesting.

I mean, frankly, you have
an edgy, interesting

-textile assemblage here.
-Mm-hmm.

TIM:
Sewing a knit

to a woven...

-is really difficult.
-Yeah. I'm...

Well, I'm challenging myself.

Just be really

mindful and watchful

-during the fitting.
-Yes.

I'm mixing denim with tweed

and tweed has
a tendency to stretch.

I have to make sure
this fits the body

in all the right places.

-Cornelius.
-Hi, Tim.

-What is that, a golf course?
-Um, it's a golf course.

-TIM: You saw it
from the helicopter? -Yeah.

CORNELIUS: I saw pops of color
that were really bright,

so I wanted to mix colors
and create a textile

-within a textile. -Okay.
I love what you're doing here.

-And I had these colors, but...
-Mm-hmm.

...they kind of look like
cheese and ketchup.

-TIM: [laughs]
-So... [chuckles]

I wanted to have, like, a strong
cap sleeve and segment it.

-Bear with me.
-Mm-hmm.

You have such interesting

-and smart seam lines happening
in this dress. -Mm-hmm.

Why aren't you letting them
guide you

with this layering treatment?

-Get rid of these amoebas.
-Right.

'Cause I could totally,
instead of having it

-so tiny, have it
come like this. -Exactly.

-Look how beautiful
that would be. -You're right.

This is the actual silhouette.

When the model walks the runway,

all this piece is going
to be inflate in the back.

If you take
this engineering away,

is it just a basic dress?

Hmm.

Well, I see a skyline.

LAURENCE:
Yes. New York City is...

beautiful and...

crazy at the same time.

-Yes. [chuckles]
-So, the top

is a strong part
and this is, like,

the lines of New York City.

The bottom of this dress,
it will be

short in the front
and it's gonna go, uh...

a little bit longer in the back.

-I'm going to use this fabric.
-Have you ever

-used a print?
-I don't think so.

I don't think so either.
Pushing yourself.

I have to change it
a little bit.

You do. I'm excited.

When I was watching
the city, I got a dark, gothy

-superhero vibe, 'cause I'm
looking over the city, -Mm-hmm.

-and it's like a protecting
vibe. -Mm-hmm.

-DEXTER: And it's denim.
-Coated.

Yeah, it's coated denim.

This is my shoulder shape
that I'm gonna place

kind of right here
and do zippers around it.

So you're building up
the shoulder.

But in no way, shape or form,
like the one I did before.

-It's more like a wing because
we were flying. -Okay.

Then underneath, I wanted to do
a full lace dress

and then double layer it
where it's inappropriate,

so that there's no business.

-It's certainly editorial.
-Yay.

But I'm worried about time.

Yeah, me too.
[laughs]

-So do it.
-Okay.

-Thank you, Dexter.
-Sweet. Thanks, Tim.

Okay. So, I plan
on doing a jumpsuit

and a jacket. I want it to be

a rain jacket, so I grabbed

textiles that are rainproof.

-You're using all three
of these? -Yes.

Well, I also grabbed, like,
a lot of different fabrics.

Like this one, and this one,

-and then this is a...
-Did you buy the yellow fabric?

Yeah, just in case.

Just in case of what?
[laughs]

You need to...

limit your range of textiles.

You can't have everything
and the kitchen sink.

NATHALIA: Tim is right.
So, I'm gonna try to switch

basically my whole idea around

and I have to repattern
the whole thing.

So, it's a lot of work and
I have, like, six hours left.

-All right, I'm intrigued,
talk to me. -[chuckles]

-I love the feeling
of the helicopter. -Hmm.

This sort of thing came
into my head,

this sort of, like,
wobble thing.

So, I kind of wanted to do,
like, an exaggerated

-drop waist vest, just like...
-Oh, this is a vest? -Yes.

But she's not wearing anything
underneath it, right?

So, this is gonna be like
the undergarment.

I'm thinking of doing,
kind of like

a little turtleneck,

sleeve shirt here.

Oh, I see.

What about this...

pastel pink says power?

Why have you taken
her figure away?

I don't know,
I just like the idea that,

like, being a woman,
you don't have to be, like,

it doesn't have to be,
like, form-fitted.

-I mean, I don't disagree
with you. -Yeah.

I'm just thinking about how
this is going to appear

very boxy, kind of milk cartony.

You are incredibly creative,

-incredibly innovative.
-Yeah.

And as far as I'm concerned,
you've been on the bottom

way too many times
for my comfort level.

Whatever's going on with this

piglet dress

needs to be changed.

But I literally have
no idea what to do.

TIM:
I think you have a number of

design issues you really
need to contend with.

ERIN: Panic is kind of
just setting in right now.

I don't know what I'm doing.

♪ ♪

TIM:
I think you have a number of

design issues you really
need to contend with.

This pink jacket

looks like student work.

And it's not reading,
you know...

editorial.

TIM:
I would like you to just ask

what's gonna make this smashing,
what's gonna make this win,

what's gonna put me on the top?

-Yeah. -And what will
put you on the top,

I can already answer,
it's you just being you.

-Thank you, Erin.
-Thank you. Yeah.

All right, designers.
I am very excited

about what you're doing.

You're all being very ambitious.

Watch the fitting carefully,
and I will see you

-in the morning. Thank you,
everyone. -ALL: Thank you, Tim.

Bye.

So, this is really cute.

MAH-JING:
That tweed, child. Ugh.

It was stretching
while I was sewing it,

so I'm a little bit
nervous to see

exactly how good
it fits my model.

The more I'm looking
at this dress,

it's just looking
like a Band-Aid,

a little bit of labia going on,
and a piglet.

ERIN: Um, Dexter,
do you have the model list

with their measurements?
I'm starting all over again.

It's five minutes

until the model comes in

and this thing
needs to go in the trash.

[indistinct chatter]

NATHALIA:
Hey, girl.

-LAURENCE: Good.
-Hello.

-RIK: Try this one on you.
-ERIN: Oh, my God,

this thing is hideous.

Now, I'm doing plan, like, D.

NATHALIA:
Okay. Perfect.

ROBERI: It's going to be
a little bit loose.

I want the whole silhouette
to be a little bit flowing.

NATHALIA:
Like, I want them fitted,

but like, not too fitted.

DEXTER: [sighs]
Okay. Here we go.

I have nothing made.

It's just an idea and a hope

and a prayer and a dream.
I'm gonna make it really long,

-and in the morning, I'm gonna
cut it and finish it. -Okay.

Thank God,
I'm looking around the room,

and a lot of people are
in the same boat.

ERIN:
My model-- she inspired me.

She, like, had faith in me.

I start a simple A-line dress

with, like, a metallic tweed.

Ooh, I like this.

Yeah, I feel so much better.

MAH-JING:
Well, you know, this textile is

beautiful by itself,
so it doesn't take much.

NATHALIA: It's the end
of the day, and it's, like,

damn, my garment--

it just doesn't look great.

What are you talking about,
Nathalia?

I just feel like this...
this is clashing.

Everyone else's looks okay,

whereas mine looks
like a costume.

It's an editorial look.

NATHALIA [sighs heavily]:
I just wish

I stuck to my original idea.

[quietly]: No, Nathalia,
stop crying. You're fine.

All you got to do
is the little facing. That's it.

Nathalia is an amazing designer

and she always tells me

to just stick with my gut.

And I think that she needs

-to stick with hers.
-[sniffles]

DEXTER: Nathalia and I, like--
our personalities

just don't mix,
but I'm looking at her, and

I'm watching her break down,
and it's breaking my heart.

Here, keep pushing through.

-Don't let them see you break.
-Thanks.

NATHALIA: I'm literally
spiraling into an abyss.

I feel like I'm going home.

[sniffles]

[crying]: I didn't think
that this competition

was gonna be this difficult.

Do the shake!

-Cha, cha, dress. -DEXTER: Now,
I just have to finish

my jacket,
and then finish the sleeves,

and then the other thing
I have to do,

and the other thing
I have to do.

I have an editorial look.

It's really

on the dark side, though.

I don't want
to send a boring look

down the runway.
On the same note, I don't

want to get eaten alive
by Zac Posen.

-So I'm trying
to just keep it cute. -Mm.

-Good morning, designers. -Good
morning. -Good morning, Tim.

Your models will be in very
shortly. You will have an hour

to send them to the Sally Beauty
Studio and the Mary Kay

Color Design Studio. Use the
JustFab wall very thoughtfully,

-and we'll see you
a little later. -Thank you.

-Thank you, everyone. -Thank
you, Tim. -Thank you, Tim.

NATHALIA: I feel better today,
but I'm still nervous.

I wish I had more time
to redesign what I did,

but at this point,
I just want to get it done.

CORNELIUS:
I am excited about this look.

It's very interesting,
and it's very intricate,

and I'm pretty sure
it's very editorial.

This has to be
the comeback moment for me,

so I have to make it work.

Ooh!

-Hi.
-Hello.

RIK:
Hi.

Hi.

-I'm coming in two minutes.
-I'm coming, too.

Katrina, I don't know how,
but I got the dress done.

I'm gonna have you try it on
in two seconds.

-Are you wearing
black underwear? -Yeah.

Are they cute and lacy?

♪ My kind of girl. ♪

Ooh, wait. This actually looks
really dope.

I'm feeling really good about
this. I can't believe that

from one of the worst things
that I ever started to create

to this in that amount of time.

Oh, my God,
this looks so much better.

-[blow dryer whirring]
-GREGORY: We're Sally Beauty.

We'll always
make you beautiful.

It's a long, kind of, like,

halter dress, very ethereal,

so I kind of just want
to pull it back.

Keep all of it loose like this.
I want to add

a little soft, soft wave.

RIK:
I trust your gut.

I like the idea of her having,

like, a Jessica Rabbit
one-eye swoop.

Sure. Just contain this
into something really

-clean and chic.
-I love that.

I was thinking maybe,
like, a bowl cut.

-Street style, Stockholm.
-Yeah, I think that works.

You know how one time I did that
really intense glitter eye?

-Yeah. Okay. -I want to do that
again, but with blue.

We have a blue called "azure,"

-and then another blue called
"midnight star." -Perfect.

-We'll make that sparkle
a little bit. -I love that.

-I want her to just look regal
in a sense. -Yeah.

-Like glowy and bronzy.
-Yeah.

That's called "French roast."

Then we do an eyeliner.

Look at the beautiful texture
of that.

-And then, on the lip,
downtown Brown. -Yeah!

Designers, in ten minutes, you
and your models and I are going

down to the runway, all right?
Ten minutes, everyone.

MAH-JING: I really want
to win this challenge.

I'm ready to impress
the judges, show them

there is a lot of talent
inside of me,

and I'm just getting started.
It looks cool.

ERIN: I love Mah-Jing's.
I think he really

pushed himself 'cause
that looked really difficult.

Okay.

TIM: All right,
designers and models,

the time has come.

We're headed down to the runway.

-Oh, my God, I feel so good.
-Good. Roberi?

-Yes, sir. -Go to the runway
and have a good time.

-Nathalia? -DEXTER:
If the judges can think outside

of the box, I think Nathalia's
jumpsuit is super cool.

I can't stop imagining this,
like, hot superhero photo sh**t.

Hello, everybody,
and welcome to the runway.

As you know, in fashion, one day
you're in, and the next day,

you're out. This group is
getting smaller and smaller.

-Is it getting intense?
-[all voicing assent]

-It's getting real.
-You see the carrot dangling?

-[laughter] -Yeah. -This is
a very exciting challenge.

You were sent off
in a helicopter

to have an aerial tour
of New York City.

-Did you guys like it?
-Yeah. -We loved it.

-Really? I think it's so scary.
-[people voicing assent]

-I've done it, too.
-[laughter]

-No one was scared?
-Yeah.

-I was gonna say you and me.
-[laughter]

Roller coasters, helicopters--
not our thing.

For this challenge, you were
to create an editorial look

for a powerful woman who is
ready to conquer the world.

You were to think bold,
high fashion,

and drama,
and as you know, the winner

of today's challenge
will receive a spread

in Marie Claire magazine.

All right,
let's say hello to our judges.

First, we have creative director
of Brooks Brothers Women

and fashion designer, Zac Posen.

-Hi, designers.
-Zac. -Hi, Zac.

Creative director for Marie
Claire magazine, Nina Garcia.

-Hello, everyone.
-Nina. -Today we have

Anne Fulenwider, editor-in-chief

of Marie Claire magazine
and new mentor of the

upcoming season of
Project Runway All Stars.

-Hi, again, designers.
-Hi.

And Camilla Belle, starring
in the film The Mad Whale.

-Welcome.
-Thank you for having me. Hi.

Also, we have Tim Gunn here
for the runway show.

And as you know,
he's your mentor,

and will not be
judging your looks.

We also have
an anonymous runway show,

so we, the judges, will
not know who made which look.

All right, let's start the show.

♪ ♪

DEXTER: I actually think
my look is super cool.

It's really
on the dark side, though.

I like the hood.

DEXTER:
There's nothing wrong

with being a little dark.

I love it!

NATHALIA:
I feel a little bit relieved

because it doesn't look
that bad.

I think the pants
look really good,

and the jacket looks cute.

I think I'll definitely
be safe today.

ROBERI:
I think she looks gorgeous.

I think she looks beautiful.

I got this feeling of freedom,

and empowerment, and
that's what I wanted to create.

MAH-JING: I finally feel like
I'm creating a look that speaks

to who I am as a designer.

I feel like
I've been holding back so much

-throughout these challenges.
-It came out really cool.

I'm feeling like I got this.

CORNELIUS: It looks chic,
it looks sophisticated.

And it looks like
an empowered businesswoman.

I'm hoping that they love it.

LAURENCE:
I love how she looks.

She looks exactly
how I want her to look.

She's sexy, she's strong
and beautiful.

ERIN: It really kind of shows
who I am as a designer.

It's fun, it's energetic,
it's colorful, it's sparkly.

I mean, I would definitely
wear this dress.

RIK: I definitely took a risk
with this look,

especially making my own
fabrication and print.

-It looks good.
-RIK: I hope it pays off.

I hope to be in those pages
of Marie Claire.

We have just learned which
designer created which look.

If I call your name,
please step forward.

Laurence.

Roberi.

If I've called your name,
congratulations.

Your scores have qualified you
to move on

to the next round.
You can leave the runway.

-Thank you.
-Thank you.

HEIDI: The six of you have the
highest and the lowest scores.

One of you will be named
the winner,

and one of you will be out.

Mah-Jing, tell us about your
inspiration and your look.

Okay. While I was
in the helicopter,

I've seen some containers
that had

an array of color
between, like, green and red.

And then, I also noticed
that the water had

a beautiful sparkle to it,

so I wanted to take those two
elements and fuse together,

and I wanted my woman
to feel powerful,

kind of, like, an, um...
an African queen.

So, I found this beautiful tweed
with different colors in there

and specs of metallic,
and I took denim

and stitched it on top
to create my... like a print.

Mah-Jing, I really love this.

-Yay!
-I think...

-Mah-Jing, you crack me up.
-[laughter]

When I see it from here,
I can see

almost your perspective from
an aerial view looking down.

And what I love about this

is the mix of materials,
the hard and the soft.

I love her silhouette. She looks
powerful, she looks fashionable.

-I love it. -Thank you. -HEIDI:
Camilla, what did you think?

I really love this look,
Mah-Jing. Congratulations.

-Really?
-And she's a

powerful woman.
You can see that 100%.

The color combination--
it's extremely flattering.

ZAC:
I think from the last challenge,

having your mother come really
put some charge into you

for this powerful woman.

Well done.

Oh.
[laughs]

Nathalia, tell us
about your inspiration

-and your look. -When were
in the helicopter ride, I saw

all these buildings
that had, like, this reflective

silver sheen to them.
I was also

inspired by the contrast
of the sky and the water,

and that's why
I chose the color blue.

To me, it's more of a Power
Ranger than a power woman.

It has that quality of a kid's
costume, and I have four kids

so I've seen a lot
of those costumes.

She's just missing the helmet.

Beam me up, Scotty.

She looks like
she's going to Comic-Con.

ANNE:
I think that the shiny fabric

seemed like a gimmick,
and the rest of it

doesn't seem like
a fashion designer designed it.

HEIDI:
Thank you, Nathalia.

Erin, tell us about your look
and your inspiration.

I really liked the feeling
of being in the helicopter.

It's kind of, like,
this funny feeling, so I

wanted, like,
a playful overall vibe.

Originally,
I had something different,

and I was overdesigning
like crazy

'cause I was, like, "Oh, no,
I've been in the bottom. Like,

I got to amp it up." And then,
after my critique with Tim,

I realized
that I just need to chill out.

-So does it mean you scrapped
your first look? You did? -Yeah.

I like it more when it's moving
than standing still.

When it was in movement,
the skirt flowed.

You could see the reflection

of the light on the bottom.

I think this is a great dress
for an editorial.

It would read in a photograph
really, really well.

I think this dress looks
like a lot of fun.

It's a little feminine and
frilly without feeling silly.

You would feel very confident
wearing that dress.

There's something very relaxed
about it and cool.

NINA:
Is it the best dress here?

No. Is it the best dress
from you?

Absolutely not. But it is
a safe dress for you.

Rik, tell us about
your inspiration and your look.

I was inspired by a couple
different things.

I just kind of
took that ethereal

timeless feeling
of being in the air,

and the Statue of Liberty,

which, of course,
has this gorgeous drapery,

-and I actually
created the print. -Oh, wow.

I just wanted it
to be something very dramatic

and something
that would definitely

pop on the pages
of Marie Claire.

ZAC:
When your model came out,

it was, like,
a stunning entrance.

You really had that wow moment.

It moved beautifully, the silver
accents came out, and then,

as she walked past me, the back.

-♪ Wah-wah. ♪
-ZAC: And then I thought

toga party
and dirty fabric over,

-like, the little pencil dress.
-Okay.

Looks like an apron. No?
Sort of? Draped.

-Yeah. -Draped.
-CAMILLE: It just felt

very incomplete, and I also
didn't totally understand it.

And even the silver straps here.

That throws me off, too, so

-it feels like many
different things. -Mm-hmm.

Rik, I absolutely love
this dress.

When your model came down
the runway,

I was blown away.
It looks beautiful on her.

I think
if you looked on the runway,

it makes the biggest statement.

I love that you made your own
fabric. I like the asymmetry.

I love that you start big

on the bottom and go smaller
and smaller.

I think
that's a really great detail.

I think the silver straps
make it fashion.

I forgive you for the back.
[laughs]

-Thank you.
-I'd like to just

go on record
of saying this is

one of my favorite,
favorite looks today.

I think
you really pulled something

dramatic and magnificent off.
Congratulations.

Thank you. I appreciate that.
Thank you.

HEIDI:
Cornelius,

tell us about your inspiration
and your look.

Being on the helicopter,
I took inspiration from

the buildings
that are protruding forward

and setting back, and also from

the golf course and how it's
shaped, and I decided to create

something that's, like,
a layering effect.

The dress itself has been
landscaped really well.

-Thank you.
-HEIDI: This was

my favorite look
today on the runway.

-Awesome. -She looks
super powerful, she looks

fashion forward,
she looks super chic.

I love the pop of color.

It kind of looks
like feathers in a way.

-Mm-hmm.
-She's business,

but she's also fun
at the same time.

I think she looks perfect.

-I would love
to wear that dress. -Awesome.

ANNE:
Even the length of the sleeve.

It's a little longer than usual,

-and I think that makes it look
-Mm-hmm.

even more fashion forward.

Congratulations.
I'm your new customer.

Thank you so much.

Dexter, tell us about your
inspiration and your look.

When I was flying
over New York City,

just being able to see

into people's windows gave me

a voyeuristic feeling

and so I really wanted to, like,

play with that with lace.

I love editorial.

I think it's about pushing
boundaries and silhouettes

and so, um, you know,
I took a risk.

I love the thing you said about
the windows and the voyeurism.

I love that you chose a fabric
that alludes to that.

I get a really great sense
of who your girl is.

This is very different
from anyone else on the runway.

This is a goth girl,
and this is,

I could see her wearing
wearing on stage,

and if that's what you wanted,
then that's

a great execution of what
you wanted to do,

but I think that the shoulder

gimmick feels gimmick
or costume-y.

I just don't think
it says fashion.

It doesn't say editorial.

Actually, it just looks
very familiar to me.

HEIDI: I didn't love this look,
I have to tell you.

I'm a little scared of her.

-Okay.
-I was also

surprised to see
this jacket again.

It is very similar

to one challenge that
we had a few weeks ago,

and that jacket was already
a big discussion then,

so I'm surprised
to see it again.

NINA:
I did like

your jacket
for that urban jungle

challenge that we did.

However, to see it again kind of
misses the element of surprise,

and actually,
the element of surprise,

that's what you have up
the sleeve that some don't.

That's your joker

and you already played this one.

Thank you, Dexter.

Cool.

HEIDI: Okay, we have heard
what you had to say.

We're going to take a closer
look at your designs,

have a little chat and then

I'll call you back
onto the runway.

-Thank you.
-Thank you.

HEIDI: The winner of Project
Runway will receive $100,000

to launch their line;
a year's supply

of Sally Beauty products,
along with $25,000 in cash;

travel and hotel accommodations
to inspiring destinations

around the world from
Best Western Hotels & Resorts;

a new Lexus IS;

from Mary Kay, an entire year's
worth of beauty products

for their fashion shows
and professional

makeup artist services
for their debut show;

a complete sewing
and crafting studio

from Brother Sewing
and Embroidery;

and the winning designer
and model will receive

a fashion spread
in Marie Claire magazine.

Hi.

HEIDI:
Hi, Tim.

Hello, ladies.

TIM:
And Juanita.

So, we have Alysia

-wearing Mah-Jing.
-Yeah.

He seemed so surprised today

when we all loved his dress.

ZAC:
It looks different up close.

It's so interesting,
the illusion of the runway.

I thought it was the opposite.

I thought it was
the denim underneath.

-ANNE: But it's denim on tweed.
-CAMILLA: Yeah.

I think the denim on the side
is really slimming, too.

-Contours.
-The figure... completely.

TIM:
Alla is wearing Cornelius.

-That I love.
-ANNE: This is great.

-I love the fabrics...
-Ooh, yes.

-that he chose, everything.
-Stroke everything.

But this, too, this is a new way

of cutting, don't you think?

-ZAC: Sure. -To do the curve
like that, isn't this, like,

-a great pattern here?
-I feel, like, it's also

a new form of finish and focus
from him.

I also feel

-a renewed sense of confidence.
-HEIDI: Good.

TIM: And we have Juanita
wearing Erin.

-I think this would sh**t
so well. -NINA: So well.

-ANNE: Yeah.
-HEIDI: Look at all this.

Beautiful neckline.

I mean, it has

so many great options.

-I like it.
-I really like it.

ANNE: I like it a little less
close up.

Close up, this is
really k*lling me.

ZAC:
It's a reflective fabric.

I kind of think it gives it
the edge it needs.

-I agree.
-And it gives it

an avant garde quality,

but I like that there's, like,

-an A-line shape here...
-Mm-hmm.

...and then she has
the volume pleating

-in the back there. -ANNE: It's
a really great fabric.

-NINA: The fabric makes it sing.
-ANNE: It's everything.

-It's everything.
-It's everything. Yeah.

-It's really...
-It's a charming dress.

-Yeah.
-It's charming.

ZAC:
Wow.

-Oh. -It doesn't improve
on closer inspection.

-No. -No.
-HEIDI: It's too costume-y.

To me, she just needs a helmet
and then she's ready to fight.

-[laughing] -HEIDI: She thought
that this looked too simple.

-And she added...
-HEIDI: So, she just added that.

But what's too simple
is the cut of the leg.

It just is really basic.

-Even here, the shoulders.
This is straight. -Right.

-ZAC: It's a sheared end.
-Here, you have a...

-Yeah, it's ruching.
-Right, right.

I mean, that is no bueno.

-ANNE: Here comes my dress.
-ZAC: Yeah.

-[laughter]
-HEIDI: I think you were

the only one that liked
this dress.

ANNE:
I loved it.

You couldn't even see that.

ZAC: Hidden ray of reflection,
but in the back,

I was just so disappointed.

This is just strapped on.

-Needs instructions.
-ZAC: Sure. -Exactly.

He doesn't need
the underdress at all.

-Yes. -I would just take
the white dress out altogether.

HEIDI:
This is so witchy to me.

-NINA: Witchy, witchy.
-ZAC: Hmm.

This jacket, sadly, it's just...

-It's the same exact cut
besides these top pieces. -No.

-ZAC: His last one.
-NINA: No, the other one

-was better made.
-ZAC: In the body.

This is not fitting,
it's just...

HEIDI: No.

-I think it's very gimmicky.
-CAMILLA: Yeah.

I liked his textile choice,

but he really didn't

-do much with it.
-Actually, I forgot

to ask him,
did he do the lingerie as well?

Aren't you wearing
your own undergarments?

-Yes. -[gasps]
-ZAC: They are.

No kidding.

ZAC:
I was gonna ask, but...

ANNE:
That's really disappointing.

HEIDI:
Now knowing that this lingerie,

he didn't make, I don't like
because, to be honest,

this, I thought this
Chris Garcia was, like,

okay, that's something
cool here,

but he didn't even make that.

Okay, so...

have we made our decision?

The six of you
represent the highest

and the lowest scores.

One of you will be
named the winner

and one or more of you
will be out.

Cornelius...

...congratulations,

you are the winner
of this challenge.

Oh, my God.

How do you feel?

I'm really thankful that I can

just show you guys more,
so I'm excited.

As you know, your look
will be featured

in an upcoming issue

of Marie Claire magazine.

That's really exciting.
Thank you.

You're in.
You can leave the runway.

Thanks, guys.
Good luck.

I'm really excited to work

with Nina and Anne.

And I'm just really

excited that my look

is gonna be featured

in Marie Claire magazine.

First win.

-LAURENCE: Oh, nice.
-Yay!

-CORNELIUS: Yes, I feel good.
-LAURENCE: Yes.

-I'm so excited.
-Congrats.

I feel good about the win,

but I'm not gonna be
c*ck about it.

I'm just really excited

to move forward.

HEIDI:
Mah-Jing.

Erin.
You're both in.

You did a fantastic job.
You can leave the runway.

-Thank you.
-Thank you.

Dexter...

your look felt

way too goth,

and, as you know, we have seen

these shoulders before from you

and they did not go over so well

the very first time we saw them.

Yeah.

Nathalia.

Your look was too costume-y.

It reminded all of us

of a superhero,

and not in a good way.

Rik.

We do appreciate that

you made your own textile,

but other than that,

it was a miss

and a mess.

Rik...

...you're in.

-You can leave the runway.
-[softly]: Thank you.

Nathalia.

Dexter.

One of you will be out.

Nathalia...

...you're out.

I'm really sorry.

-I wish you the best of luck.
-Thank you so much.

Auf Wiedersehen.

Thank you so much
for everything.

I was not proud of my garment.

I knew that it looked costume-y.
I knew that

it wasn't the best work

that I've done,
but I learned

so much.

-NATHALIA: Hi.
-CORNELIUS: You're in?

No, I'm out.

-What?
-What?

-Yeah.
-ERIN: Nathalia.

They just said that my garment

was poorly constructed
and it was

-too costume-y.
-RIK: Wow.

-ROBERI: Aw, sweetie.
-NATHALIA: It's okay.

I learned a lot

and I'm just happy I got
to make it this far.

-You should be proud of
yourself. -NATHALIA: I'm happy.

RIK:
Yeah.

HEIDI:
Dexter.

I'm sorry. You're out, as well.

I'm sorry, Dexter.

-Don't be sorry.
-I wish you all the best.

I did it to myself.

-Auf Wiedersehen.
-I had a great time.

Thank you guys so much.

Damn, I got the boot.

It's heartbreaking,

but I definitely stayed true

to myself, so...

how... what-what else
can I ask for?

[sighs]
I'm out.

-What?!
-[Dexter sighs]

-LAURENCE: Oh, wow.
-MAH-JING: Really?

-Yeah.
-Oh, no.

Oh, it was a fun run, guys.

-[Dexter sighs]
-ERIN: I'm so happy

-I got to meet you.
-Me, too.

CORNELIUS:
Don't cry, Nathalia.

I'm not going to cry.

Don't you cry.

-I knew I was going home.
-MAH-JING: Whoa.

Yeah, it just didn't go
quite how I planned it

and I don't know what
I was thinking, but I still,

like, love it and I'm happy

and... it's just done.

But congrats to you guys
for being

-top six. -DEXTER: Yeah.
-LAURENCE: Thank you.

That's so weird.

MAH-JING:
Damn.

DEXTER:
Congratulations, guys.

MAH-JING:
Wow.

Stop it, though.

TIM:
Wow.

I wasn't expecting this.

How is everyone?

-DEXTER: I'm good.
-Good.

Really?

Yeah, I'm just grateful

that I got to be here
and get this far.

TIM:
Yeah.

And we're going to miss
both of you tremendously.

-Thank you.
-I have to send you both

to the workroom to clean up
your spaces, okay?

-DEXTER: Guys, have fun.
-LAURENCE: Bye, guys.

NATHALIA:
Thank you, Tim.

-It was so nice meeting you.
-Well, we love you.

-Thank you so much.
-We'll see more of you.

-Thank you.
-Dexter.

-DEXTER: This was wonderful.
-We'll see more of you. We know.

-[laughter] -DEXTER: Keep it
interesting, guys.

Don't be boring.

Love you, babe.

DEXTER: This one of the hardest
things that I've ever done

in my entire life...
but it was worth it.

I'm so happy with what
I've accomplished here.

I'm confident in the fact that
people out there will find me

to do the things
that I really want to do

and I can't wait to see

what happens next.

NATHALIA:
This is just the beginning

of my career
and I'm gonna continue

to design,
I'm gonna continue to create.

It's crazy.

I still can't believe it.

I'm, like, eliminated
and I'm still like,

"Wait, I was on Project Runway."

HEIDI:
Next time on Project Runway.

Go big and you better buckle up.

It looks like a movie set.

-TIM: And they're off.
-ERIN: In five minutes,

you can't really
have a strategy.

There's no way.

These things are heavy!

RIK:
Bye, Tim!

-Oh... my...
-I told you

-God.
-it was gonna do that.

Uh-oh.
I don't want you

to make it too costume-y.

It was kind of messing
with me, mentally.

[shouts]

-I loved the show today.
-I loved it.

It is super sexy and sheer.

-It's a little scary.
-I don't want to see that.

[imitates motor running]

HEIDI: Visit myLifetime.com
to learn more

about the fashion you've seen
on tonight's show.